==> org-lsst-ccs-subsystem-refrig-buses-4.2.0-sources.jar: org/lsst/ccs/subsystem/refrig/data/CryoCompState.java <==
package org.lsst.ccs.subsystem.refrig.data;

import java.util.ArrayList;
import java.util.List;
import org.lsst.ccs.subsystem.refrig.constants.CompConditions;
import org.lsst.ccs.subsystem.refrig.constants.CompLatches;
import org.lsst.ccs.subsystem.refrig.constants.CompSwConds;
import org.lsst.ccs.subsystem.refrig.constants.CompSwitches;
import org.lsst.ccs.subsystem.refrig.constants.CompTypes;

/**
 *  Contains the state of a cryo compressor.
 *
 *  The order of the elements in each list determines the order they appear in the GUI
 *
 *  @author Owen Saxton
 */
public class CryoCompState extends CompState {
    
    public static final List<Integer> SWITCHES = new ArrayList<>();  // Determines presence & order in GUI
    static {
        SWITCHES.add(CompSwitches.SW_ENABLE);
        SWITCHES.add(CompSwitches.SW_ENABLE_ALERTS);
        SWITCHES.add(CompSwitches.SW_LIGHTS);
        SWITCHES.add(CompSwitches.SW_HEATER);
        SWITCHES.add(CompSwitches.SW_ORIFICE_VALVE);
        SWITCHES.add(CompSwitches.SW_COOLANT_VALVE);
        SWITCHES.add(CompSwitches.SW_BYPASS_VALVE);
        SWITCHES.add(CompSwitches.SW_SURGE_HEATER);
    }
    public static final List<Integer> LATCHES = new ArrayList<>();  // Determines presence & order in GUI
    static {
        LATCHES.add(CompLatches.LATCH_DISCHARGE_TEMP);
        LATCHES.add(CompLatches.LATCH_DISCHARGE_PRESS);
        LATCHES.add(CompLatches.LATCH_SUCTION_TEMP);
        LATCHES.add(CompLatches.LATCH_OIL_LEVEL);
        LATCHES.add(CompLatches.LATCH_AFTER_COOLER);
        LATCHES.add(CompLatches.LATCH_POWER);
        LATCHES.add(CompLatches.LATCH_SENSORS_VALID);
        LATCHES.add(CompLatches.LATCH_SMOKE_DETC);
        LATCHES.add(CompLatches.LATCH_EXT_PERMIT);
    }
    public static final List<Integer> CONDITIONS = new ArrayList<>();  // Determines presence & order in GUI
    static {
        CONDITIONS.add(CompConditions.COND_KEYSWITCH_ON);
        CONDITIONS.add(CompConditions.COND_CMP_ENABLED);
        CONDITIONS.add(CompConditions.COND_CMP_WAITING);
        CONDITIONS.add(CompConditions.COND_CMP_POWERED);
        CONDITIONS.add(CompConditions.COND_DISC_TEMP_VALID);
        CONDITIONS.add(CompConditions.COND_DISC_PRESS_VALID);
        CONDITIONS.add(CompConditions.COND_SUCT_TEMP_VALID);
        CONDITIONS.add(CompConditions.COND_SUCT_PRESS_VALID);
        CONDITIONS.add(CompConditions.COND_OIL_LEVEL_VALID);
        CONDITIONS.add(CompConditions.COND_CURRENT_VALID);
        CONDITIONS.add(CompConditions.COND_VOLTAGE_VALID);
        CONDITIONS.add(CompConditions.COND_CURR_SENSOR_ERR);
        CONDITIONS.add(CompConditions.COND_LATCHES_CLEAR);
        CONDITIONS.add(CompConditions.COND_CMP_ON_8HRS);
        CONDITIONS.add(CompConditions.COND_POWER_LED);
    }
    public static final List<Integer> SW_CONDITIONS = new ArrayList<>();  // Determines presence & order in GUI
    static {
        SW_CONDITIONS.add(CompSwConds.SWC_CMPR_POWER);
        SW_CONDITIONS.add(CompSwConds.SWC_DISC_PRESS);
        SW_CONDITIONS.add(CompSwConds.SWC_DISC_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_SUCT_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_PLATE_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_PHASE_SEP_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_OIL_LEVEL);
        SW_CONDITIONS.add(CompSwConds.SWC_DISC_TEMP_LOW);
        SW_CONDITIONS.add(CompSwConds.SWC_PRESS_DIFF);
    }

    public CryoCompState() {
        super(CompTypes.TYPE_CRYO);
    }

    private static final long serialVersionUID = 5225867568451833713L;
}

==> org-lsst-ccs-subsystem-refrig-buses-4.4.11-sources.jar: org/lsst/ccs/subsystem/refrig/data/CryoCompState.java <==
package org.lsst.ccs.subsystem.refrig.data;

import java.util.ArrayList;
import java.util.List;
import org.lsst.ccs.subsystem.refrig.constants.CompConditions;
import org.lsst.ccs.subsystem.refrig.constants.CompLatches;
import org.lsst.ccs.subsystem.refrig.constants.CompSwConds;
import org.lsst.ccs.subsystem.refrig.constants.CompSwitches;
import org.lsst.ccs.subsystem.refrig.constants.CompTypes;

/**
 *  Contains the state of a cryo compressor.
 *
 *  The order of the elements in each list determines the order they appear in the GUI
 *
 *  @author Owen Saxton
 */
public class CryoCompState extends CompState {
    
    public static final List<Integer> SWITCHES = new ArrayList<>();  // Determines presence & order in GUI
    static {
        SWITCHES.add(CompSwitches.SW_ENABLE);
        SWITCHES.add(CompSwitches.SW_ENABLE_ALERTS);
        SWITCHES.add(CompSwitches.SW_LIGHTS);
        SWITCHES.add(CompSwitches.SW_HEATER);
        SWITCHES.add(CompSwitches.SW_ORIFICE_VALVE);
        SWITCHES.add(CompSwitches.SW_COOLANT_VALVE);
        SWITCHES.add(CompSwitches.SW_BYPASS_VALVE);
        SWITCHES.add(CompSwitches.SW_SURGE_HEATER);
    }
    public static final List<Integer> LATCHES = new ArrayList<>();  // Determines presence & order in GUI
    static {
        LATCHES.add(CompLatches.LATCH_DISCHARGE_TEMP);
        LATCHES.add(CompLatches.LATCH_DISCHARGE_PRESS);
        LATCHES.add(CompLatches.LATCH_SUCTION_TEMP);
        LATCHES.add(CompLatches.LATCH_OIL_LEVEL);
        LATCHES.add(CompLatches.LATCH_AFTER_COOLER);
        LATCHES.add(CompLatches.LATCH_POWER);
        LATCHES.add(CompLatches.LATCH_SENSORS_VALID);
        LATCHES.add(CompLatches.LATCH_SMOKE_DETC);
        LATCHES.add(CompLatches.LATCH_EXT_PERMIT);
    }
    public static final List<Integer> CONDITIONS = new ArrayList<>();  // Determines presence & order in GUI
    static {
        CONDITIONS.add(CompConditions.COND_KEYSWITCH_ON);
        CONDITIONS.add(CompConditions.COND_CMP_ENABLED);
        CONDITIONS.add(CompConditions.COND_CMP_WAITING);
        CONDITIONS.add(CompConditions.COND_CMP_POWERED);
        CONDITIONS.add(CompConditions.COND_HEATER_ENABLED);
        CONDITIONS.add(CompConditions.COND_HEATER_POWERED);
        CONDITIONS.add(CompConditions.COND_DISC_TEMP_VALID);
        CONDITIONS.add(CompConditions.COND_DISC_PRESS_VALID);
        CONDITIONS.add(CompConditions.COND_SUCT_TEMP_VALID);
        CONDITIONS.add(CompConditions.COND_SUCT_PRESS_VALID);
        CONDITIONS.add(CompConditions.COND_OIL_LEVEL_VALID);
        CONDITIONS.add(CompConditions.COND_CURRENT_VALID);
        CONDITIONS.add(CompConditions.COND_VOLTAGE_VALID);
        CONDITIONS.add(CompConditions.COND_CURR_SENSOR_ERR);
        CONDITIONS.add(CompConditions.COND_LATCHES_CLEAR);
        CONDITIONS.add(CompConditions.COND_CMP_ON_8HRS);
        CONDITIONS.add(CompConditions.COND_POWER_LED);
    }
    public static final List<Integer> SW_CONDITIONS = new ArrayList<>();  // Determines presence & order in GUI
    static {
        SW_CONDITIONS.add(CompSwConds.SWC_CMPR_POWER);
        SW_CONDITIONS.add(CompSwConds.SWC_DISC_PRESS);
        SW_CONDITIONS.add(CompSwConds.SWC_DISC_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_SUCT_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_PLATE_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_PHASE_SEP_TEMP);
        SW_CONDITIONS.add(CompSwConds.SWC_OIL_LEVEL);
        SW_CONDITIONS.add(CompSwConds.SWC_DISC_TEMP_LOW);
        SW_CONDITIONS.add(CompSwConds.SWC_PRESS_DIFF);
        SW_CONDITIONS.add(CompSwConds.SWC_VACUUM_BAD);
    }

    public CryoCompState() {
        super(CompTypes.TYPE_CRYO);
    }

    private static final long serialVersionUID = 5225867568451833713L;
}
